@@ -4,7 +4,6 @@ use std::collections::HashMap;
 
 #[derive(Copy, Clone, Debug)]
 pub struct GlyphInfo {
-    pub size: u32,
     pub rect: Option<Rect>,
     pub metrics: fontdue::Metrics,
 }
@@ -28,14 +27,16 @@ impl GlyphCache {
 
     pub fn get_glyph(&mut self, c: char, size: f32) -> GlyphInfo {
 
+        let factor = 65536.0;
+
         // Convert size to fixed point so we can hash it.
-        let size_fixed_point = (size * 1000.0) as u32;
+        let size_fixed_point = (size * factor) as u32;
 
         // Do we already have a glyph?
         match self.info.get(&(c, size_fixed_point)) {
             Some(info) => *info,
             None => {
-                let (metrics, data) = self.font.rasterize(c, size_fixed_point as f32 / 1000.0);
+                let (metrics, data) = self.font.rasterize(c, size_fixed_point as f32 / factor);
 
                 /*
                 let mut i = 0;
@@ -53,7 +54,6 @@ impl GlyphCache {
                         .add_region(&data, metrics.width as u32, metrics.height as u32);
 
                 let info = GlyphInfo {
-                    size: size_fixed_point,
                     rect,
                     metrics,
                 };
@@ -71,4 +71,13 @@ impl GlyphCache {
     pub fn create_view(&self) -> wgpu::TextureView {
         self.atlas.create_view()
     }
+
+    pub fn usage(&self) -> f32 {
+        self.atlas.usage()
+    }
+
+    pub fn clear(&mut self) {
+        self.info.clear();
+        self.atlas.clear();
+    }
 }
